@@ -1,6 +1,6 @@
 __author__ = "Joseph D. Hughes"
-__date__ = "March 2, 2022"
-__version__ = "0.0.1"
+__date__ = "Dec 16, 2022"
+__version__ = "0.0.6"
 __maintainer__ = "Joseph D. Hughes"
 __email__ = "jdhughes@usgs.gov"
 __status__ = "Production"
